@@ -299,6 +299,7 @@ void MainWindow::createMenu() {
     pAction = new QAction("Terrain", m_pViewActionGroup); pAction->setCheckable(true); pAction->setChecked(viewMode==3);
     menuBar()->addActions(m_pViewActionGroup->actions());
     connect(m_pViewActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(onViewChanged(QAction*)));
+    setView(viewMode);
 
     // menuBar()->addAction("Reload", this, SLOT(reload()));
     // menuBar()->addAction("Find Address", this, SLOT(find()));
@@ -329,7 +330,7 @@ void MainWindow::createMenu() {
 
     m_pAccuracyAction = menuBar()->addAction("Show Accuracy", this, SLOT(onShowAccuracy()));
     m_pAccuracyAction->setCheckable(true);
-    m_pAccuracyAction->setChecked(false);
+    m_pAccuracyAction->setChecked(settings.value("ShowAccuracy", false).toBool());
     onShowAccuracy();
 
 #ifdef Q_WS_MAEMO_5
@@ -365,6 +366,9 @@ void MainWindow::createMenu() {
 
 void MainWindow::onShowAccuracy() {
     if ( !m_pAccuracyAction->isChecked() ) runJavascript("if ( radius ) {radius.setMap(null); }");
+
+    QSettings settings;
+    settings.setValue("ShowAccuracy", m_pAccuracyAction->isChecked());
 }
 
 void MainWindow::onTrafficLayer() {
